@@ -187,18 +187,30 @@ valid_service(const char *runlevel, const char *service, const char *type)
 	    strcmp(type, "needsme") == 0)
 		return true;
 
+	if (rc_service_in_runlevel(service, runlevel))
+		return true;
+	if (strcmp(runlevel, RC_LEVEL_SYSINIT) == 0)
+		    return false;
+	if (strcmp(runlevel, RC_LEVEL_SHUTDOWN) == 0 &&
+	    strcmp(type, "iafter") == 0)
+		    return false;
+	if (strcmp(runlevel, bootlevel) != 0) {
+		if (rc_service_in_runlevel(service, bootlevel))
+			return true;
+	}
+
 	state = rc_service_state(service);
-	return ((strcmp(runlevel, bootlevel) != 0 &&
-		 rc_service_in_runlevel(service, bootlevel)) ||
-		rc_service_in_runlevel(service, runlevel) ||
-		state & RC_SERVICE_COLDPLUGGED ||
-		state & RC_SERVICE_STARTED);
+	if (state & RC_SERVICE_HOTPLUGGED ||
+	    state & RC_SERVICE_STARTED)
+		return true;
+
+	return false;
 }
 
 static bool
 get_provided1(const char *runlevel, RC_STRINGLIST *providers,
 	      RC_DEPTYPE *deptype, const char *level,
-	      bool coldplugged, RC_SERVICE state)
+	      bool hotplugged, RC_SERVICE state)
 {
 	RC_STRING *service;
 	RC_SERVICE st;
@@ -213,8 +225,8 @@ get_provided1(const char *runlevel, RC_STRINGLIST *providers,
 
 		if (level)
 			ok = rc_service_in_runlevel(svc, level);
-		else if (coldplugged)
-			ok = (st & RC_SERVICE_COLDPLUGGED &&
+		else if (hotplugged)
+			ok = (st & RC_SERVICE_HOTPLUGGED &&
 			      !rc_service_in_runlevel(svc, runlevel) &&
 			      !rc_service_in_runlevel(svc, bootlevel));
 		if (!ok)
@@ -272,13 +284,13 @@ get_provided(const RC_DEPINFO *depinfo, const char *runlevel, int options)
 	}
 
 	/* If we're strict or starting, then only use what we have in our
-	 * runlevel and bootlevel. If we starting then check cold-plugged too. */
+	 * runlevel and bootlevel. If we starting then check hotplugged too. */
 	if (options & RC_DEP_STRICT || options & RC_DEP_START) {
 		TAILQ_FOREACH(service, dt->services, entries)
 			if (rc_service_in_runlevel(service->value, runlevel) ||
 			    rc_service_in_runlevel(service->value, bootlevel) ||
 			    (options & RC_DEP_START &&
-			     rc_service_state(service->value) & RC_SERVICE_COLDPLUGGED))
+			     rc_service_state(service->value) & RC_SERVICE_HOTPLUGGED))
 				rc_stringlist_add(providers, service->value);
 		if (TAILQ_FIRST(providers))
 			return providers;
@@ -292,7 +304,7 @@ get_provided(const RC_DEPINFO *depinfo, const char *runlevel, int options)
 	 * We apply this to these states in order:-
 	 *     started, starting | stopping | inactive, stopped
 	 * Our sub preference in each of these is in order:-
-	 *     runlevel, coldplugged, bootlevel, any
+	 *     runlevel, hotplugged, bootlevel, any
 	 */
 #define DO \
 	if (TAILQ_FIRST(providers)) { \
@@ -344,7 +356,7 @@ get_provided(const RC_DEPINFO *depinfo, const char *runlevel, int options)
 static void
 visit_service(const RC_DEPTREE *deptree,
 	      const RC_STRINGLIST *types,
-	      RC_STRINGLIST **sorted,
+	      RC_STRINGLIST *sorted,
 	      RC_STRINGLIST *visited,
 	      const RC_DEPINFO *depinfo,
 	      const char *runlevel, int options)
@@ -373,9 +385,7 @@ visit_service(const RC_DEPTREE *deptree,
 			if (!(options & RC_DEP_TRACE) ||
 			    strcmp(type->value, "iprovide") == 0)
 			{
-				if (!*sorted)
-					*sorted = rc_stringlist_new();
-				rc_stringlist_add(*sorted, service->value);
+				rc_stringlist_add(sorted, service->value);
 				continue;
 			}
 
@@ -420,12 +430,10 @@ visit_service(const RC_DEPTREE *deptree,
 	/* We've visited everything we need, so add ourselves unless we
 	   are also the service calling us or we are provided by something */
 	svcname = getenv("RC_SVCNAME");
-	if (!svcname || strcmp(svcname, depinfo->service) != 0)
-		if (!get_deptype(depinfo, "providedby")) {
-			if (!*sorted)
-				*sorted = rc_stringlist_new();
-			rc_stringlist_add(*sorted, depinfo->service);
-		}
+	if (!svcname || strcmp(svcname, depinfo->service) != 0) {
+		if (!get_deptype(depinfo, "providedby"))
+			rc_stringlist_add(sorted, depinfo->service);
+	}
 }
 
 RC_STRINGLIST *
@@ -437,15 +445,15 @@ rc_deptree_depend(const RC_DEPTREE *deptree,
 	RC_STRINGLIST *svcs;
 	RC_STRING *svc;
 
+	svcs = rc_stringlist_new();
 	if (!(di = get_depinfo(deptree, service)) ||
 	    !(dt = get_deptype(di, type)))
 	{
 		errno = ENOENT;
-		return NULL;
+		return svcs;
 	}
 
 	/* For consistency, we copy the array */
-	svcs = rc_stringlist_new();
 	TAILQ_FOREACH(svc, dt->services, entries)
 		rc_stringlist_add(svcs, svc->value);
 	return svcs;
@@ -458,7 +466,7 @@ rc_deptree_depends(const RC_DEPTREE *deptree,
 		   const RC_STRINGLIST *services,
 		   const char *runlevel, int options)
 {
-	RC_STRINGLIST *sorted = NULL;
+	RC_STRINGLIST *sorted = rc_stringlist_new();
 	RC_STRINGLIST *visited = rc_stringlist_new();
 	RC_DEPINFO *di;
 	const RC_STRING *service;
@@ -472,7 +480,7 @@ rc_deptree_depends(const RC_DEPTREE *deptree,
 			continue;
 		}
 		if (types)
-			visit_service(deptree, types, &sorted, visited,
+			visit_service(deptree, types, sorted, visited,
 				      di, runlevel, options);
 	}
 	rc_stringlist_free(visited);
@@ -494,47 +502,29 @@ rc_deptree_order(const RC_DEPTREE *deptree, const char *runlevel, int options)
 
 	/* When shutting down, list all running services */
 	if (strcmp(runlevel, RC_LEVEL_SINGLE) == 0 ||
-	    strcmp(runlevel, RC_LEVEL_SHUTDOWN) == 0 ||
-	    strcmp(runlevel, RC_LEVEL_REBOOT) == 0)
+	    strcmp(runlevel, RC_LEVEL_SHUTDOWN) == 0)
 	{
 		list = rc_services_in_state(RC_SERVICE_STARTED);
 		list2 = rc_services_in_state(RC_SERVICE_INACTIVE);
-		if (list2) {
-			if (list) {
-				TAILQ_CONCAT(list, list2, entries);
-				free(list2);
-			} else
-				list = list2;
-		}
+		TAILQ_CONCAT(list, list2, entries);
+		free(list2);
 		list2 = rc_services_in_state(RC_SERVICE_STARTING);
-		if (list2) {
-			if (list) {
-				TAILQ_CONCAT(list, list2, entries);
-				free(list2);
-			} else
-				list = list2;
-		}
+		TAILQ_CONCAT(list, list2, entries);
+		free(list2);
 	} else {
-		list = rc_services_in_runlevel(runlevel);
-		/* Add coldplugged services */
-		list2 = rc_services_in_state(RC_SERVICE_COLDPLUGGED);
-		if (list2) {
-			if (list) {
+		list = rc_services_in_runlevel(RC_LEVEL_SYSINIT);
+		if (strcmp(runlevel, RC_LEVEL_SYSINIT) != 0) {
+			list2 = rc_services_in_runlevel(runlevel);
+			TAILQ_CONCAT(list, list2, entries);
+			free(list2);
+			list2 = rc_services_in_state(RC_SERVICE_HOTPLUGGED);
+			TAILQ_CONCAT(list, list2, entries);
+			free(list2);
+			/* If we're not the boot runlevel then add that too */
+			if (strcmp(runlevel, bootlevel) != 0) {
+				list2 = rc_services_in_runlevel(bootlevel);
 				TAILQ_CONCAT(list, list2, entries);
 				free(list2);
-			} else
-				list = list2;
-		}
-
-		/* If we're not the boot runlevel then add that too */
-		if (strcmp(runlevel, bootlevel) != 0) {
-			list2 = rc_services_in_runlevel (bootlevel);
-			if (list2) {
-				if (list) {
-					TAILQ_CONCAT(list, list2, entries);
-					free(list2);
-				} else
-					list = list2;
 			}
 		}
 	}
@@ -638,7 +628,7 @@ static const char *const depdirs[] =
 	RC_SVCDIR "/inactive",
 	RC_SVCDIR "/wasinactive",
 	RC_SVCDIR "/failed",
-	RC_SVCDIR "/coldplugged",
+	RC_SVCDIR "/hotplugged",
 	RC_SVCDIR "/daemons",
 	RC_SVCDIR "/options",
 	RC_SVCDIR "/exclusive",
@@ -683,15 +673,13 @@ rc_deptree_update_needed(void)
 	/* Some init scripts dependencies change depending on config files
 	 * outside of baselayout, like syslog-ng, so we check those too. */
 	config = rc_config_list(RC_DEPCONFIG);
-	if (config) {
-		TAILQ_FOREACH(s, config, entries) {
-			if (!rc_newer_than(RC_DEPTREE_CACHE, s->value)) {
-				newer = true;
-				break;
-			}
+	TAILQ_FOREACH(s, config, entries) {
+		if (!rc_newer_than(RC_DEPTREE_CACHE, s->value)) {
+			newer = true;
+			break;
 		}
-		rc_stringlist_free(config);
 	}
+	rc_stringlist_free(config);
 	return newer;
 }
 librc_hidden_def(rc_deptree_update_needed)
@@ -907,13 +895,11 @@ rc_deptree_update(void)
 		deptype = get_deptype(depinfo, "ibefore");
 		if (!deptype)
 			continue;
-		sorted = NULL;
+		sorted = rc_stringlist_new();
 		visited = rc_stringlist_new();
-		visit_service(deptree, types, &sorted, visited, depinfo,
+		visit_service(deptree, types, sorted, visited, depinfo,
 			      NULL, 0);
 		rc_stringlist_free(visited);
-		if (!sorted)
-			continue;
 		TAILQ_FOREACH_SAFE(s2, deptype->services, entries, s2_np) {
 			TAILQ_FOREACH(s3, sorted, entries) {
 				di = get_depinfo(deptree, s3->value);
