@@ -717,9 +717,9 @@ svc_start(bool deps)
 			exit(EXIT_FAILURE);
 		background = true;
 		rc_service_mark(service, RC_SERVICE_HOTPLUGGED);
-		if (rc_runlevel_starting())
-			ewarnx("WARNING: %s will be started when the runlevel"
-			       " has finished.", applet);
+		if (strcmp(runlevel, RC_LEVEL_SYSINIT) == 0)
+			ewarnx("WARNING: %s will be started in the"
+			       " next runlevel", applet);
 	}
 
 	if (state & RC_SERVICE_STARTED) {
@@ -965,9 +965,12 @@ svc_stop(bool deps)
 	hook_out = RC_HOOK_SERVICE_STOP_OUT;
 	rc_plugin_run(RC_HOOK_SERVICE_STOP_IN, applet);
 
-	if (!rc_runlevel_stopping() &&
-	    rc_service_in_runlevel(service, RC_LEVEL_BOOT))
-		ewarn ("WARNING: you are stopping a boot service");
+	if (!rc_runlevel_stopping()) {
+		if (rc_service_in_runlevel(service, RC_LEVEL_SYSINIT))
+			ewarn ("WARNING: you are stopping a sysinit service");
+		else if (rc_service_in_runlevel(service, RC_LEVEL_BOOT))
+			ewarn ("WARNING: you are stopping a boot service");
+	}
 
 	if (deps && !(state & RC_SERVICE_WASINACTIVE)) {
 		errno = 0;
@@ -1233,7 +1236,7 @@ runscript(int argc, char **argv)
 	/* Change dir to / to ensure all init scripts don't use stuff in pwd */
 	chdir("/");
 
-	if ((runlevel = xstrdup (getenv ("RC_RUNLEVEL"))) == NULL) {
+	if ((runlevel = xstrdup(getenv("RC_RUNLEVEL"))) == NULL) {
 		env_filter();
 		env_config();
 		runlevel = rc_runlevel_get();
